@@ -172,12 +172,8 @@ impl Runner {
     pub fn run(self) -> Result<Option<String>> {
         // Why unsafe? See https://github.com/sayanarijit/xplr/issues/309
         let lua = unsafe { mlua::Lua::unsafe_new() };
-        let mut app = app::App::create(
-            self.pwd,
-            &lua,
-            self.config_file,
-            self.extra_config_files,
-        )?;
+        let mut app =
+            app::App::create(self.pwd, &lua, self.config_file, self.extra_config_files)?;
         app.config.general.read_only = self.read_only;
 
         fs::create_dir_all(app.session_path.clone())?;
@@ -236,6 +232,7 @@ impl Runner {
             };
 
         let mut last_focus: Option<app::Node> = None;
+        let mut last_pwd = app.pwd.clone();
 
         let mut mouse_enabled = app.config.general.enable_mouse;
         if mouse_enabled {
@@ -249,11 +246,7 @@ impl Runner {
         terminal.hide_cursor()?;
 
         // Threads
-        pwd_watcher::keep_watching(
-            app.pwd.as_ref(),
-            tx_msg_in.clone(),
-            rx_pwd_watcher,
-        )?;
+        pwd_watcher::keep_watching(app.pwd.as_ref(), tx_msg_in.clone(), rx_pwd_watcher)?;
         let mut event_reader = EventReader::new(tx_msg_in.clone());
         event_reader.start();
 
@@ -327,9 +320,8 @@ impl Runner {
                                 explorer::explore_async(
                                     app.explorer_config.clone(),
                                     app.pwd.clone().into(),
-                                    app.focused_node().map(|n| {
-                                        n.relative_path.clone().into()
-                                    }),
+                                    app.focused_node()
+                                        .map(|n| n.relative_path.clone().into()),
                                     app.directory_buffer
                                         .as_ref()
                                         .map(|d| d.focus)
@@ -343,9 +335,8 @@ impl Runner {
                                 explorer::explore_recursive_async(
                                     app.explorer_config.clone(),
                                     app.pwd.clone().into(),
-                                    app.focused_node().map(|n| {
-                                        n.relative_path.clone().into()
-                                    }),
+                                    app.focused_node()
+                                        .map(|n| n.relative_path.clone().into()),
                                     app.directory_buffer
                                         .as_ref()
                                         .map(|d| d.focus)
@@ -356,22 +347,34 @@ impl Runner {
                             }
 
                             Refresh => {
-                                // $PWD watcher
-                                tx_pwd_watcher.send(app.pwd.clone())?;
-                                // UI
-                                terminal.draw(|f| ui::draw(f, &app, &lua))?;
                                 // Fifo
                                 let focus = app.focused_node();
                                 if focus != last_focus.as_ref() {
                                     if let Some(ref mut file) = fifo {
-                                        writeln!(
-                                            file,
-                                            "{}",
-                                            app.focused_node_str()
-                                        )?;
+                                        writeln!(file, "{}", app.focused_node_str())?;
                                     };
                                     last_focus = focus.cloned();
                                 }
+
+                                if app.pwd != last_pwd {
+                                    // $PWD watcher
+                                    tx_pwd_watcher.send(app.pwd.clone())?;
+
+                                    // OSC 7: Change CWD
+                                    if !(*ui::NO_COLOR) {
+                                        write!(
+                                            terminal.backend_mut(),
+                                            "\x1b]7;file://{}{}\x1b\\",
+                                            &app.hostname,
+                                            &app.pwd
+                                        )?;
+                                    }
+
+                                    last_pwd = app.pwd.clone();
+                                }
+
+                                // UI
+                                terminal.draw(|f| ui::draw(f, &app, &lua))?;
                             }
 
                             EnableMouse => {
@@ -384,8 +387,7 @@ impl Runner {
                                             mouse_enabled = true;
                                         }
                                         Err(e) => {
-                                            app =
-                                                app.log_error(e.to_string())?;
+                                            app = app.log_error(e.to_string())?;
                                         }
                                     }
                                 }
@@ -413,18 +415,14 @@ impl Runner {
                                             mouse_enabled = false;
                                         }
                                         Err(e) => {
-                                            app =
-                                                app.log_error(e.to_string())?;
+                                            app = app.log_error(e.to_string())?;
                                         }
                                     }
                                 }
                             }
 
                             StartFifo(path) => {
-                                fifo = match start_fifo(
-                                    &path,
-                                    &app.focused_node_str(),
-                                ) {
+                                fifo = match start_fifo(&path, &app.focused_node_str()) {
                                     Ok(file) => Some(file),
                                     Err(e) => {
                                         app = app.log_error(e.to_string())?;
@@ -445,25 +443,22 @@ impl Runner {
                                     fifo = None;
                                     std::mem::drop(file);
                                 } else {
-                                    fifo = match start_fifo(
-                                        &path,
-                                        &app.focused_node_str(),
-                                    ) {
-                                        Ok(file) => Some(file),
-                                        Err(e) => {
-                                            app =
-                                                app.log_error(e.to_string())?;
-                                            None
+                                    fifo =
+                                        match start_fifo(&path, &app.focused_node_str())
+                                        {
+                                            Ok(file) => Some(file),
+                                            Err(e) => {
+                                                app = app.log_error(e.to_string())?;
+                                                None
+                                            }
                                         }
-                                    }
                                 }
                             }
 
                             CallLuaSilently(func) => {
                                 match call_lua_heavy(&app, &lua, &func, false) {
                                     Ok(Some(msgs)) => {
-                                        app = app
-                                            .handle_batch_external_msgs(msgs)?;
+                                        app = app.handle_batch_external_msgs(msgs)?;
                                     }
                                     Ok(None) => {}
                                     Err(err) => {
@@ -489,8 +484,7 @@ impl Runner {
 
                                 match pipe::read_all(&app.pipe.msg_in) {
                                     Ok(msgs) => {
-                                        app = app
-                                            .handle_batch_external_msgs(msgs)?;
+                                        app = app.handle_batch_external_msgs(msgs)?;
                                     }
                                     Err(err) => {
                                         app = app.log_error(err.to_string())?;
@@ -520,8 +514,7 @@ impl Runner {
 
                                 match call_lua_heavy(&app, &lua, &func, false) {
                                     Ok(Some(msgs)) => {
-                                        app = app
-                                            .handle_batch_external_msgs(msgs)?;
+                                        app = app.handle_batch_external_msgs(msgs)?;
                                     }
                                     Ok(None) => {}
                                     Err(err) => {
@@ -543,8 +536,7 @@ impl Runner {
                                             mouse_enabled = true;
                                         }
                                         Err(e) => {
-                                            app =
-                                                app.log_error(e.to_string())?;
+                                            app = app.log_error(e.to_string())?;
                                         }
                                     }
                                 }
@@ -570,9 +562,7 @@ impl Runner {
                                 match res {
                                     Ok(Value::Function(f)) => {
                                         let arg = app.to_lua_ctx_heavy();
-                                        let res: Result<
-                                            Option<Vec<ExternalMsg>>,
-                                        > = lua
+                                        let res: Result<Option<Vec<ExternalMsg>>> = lua
                                             .to_value(&arg)
                                             .and_then(|a| f.call(a))
                                             .and_then(|v| lua.from_value(v))
@@ -580,36 +570,25 @@ impl Runner {
                                         match res {
                                             Ok(Some(msgs)) => {
                                                 app = app
-                                                    .handle_batch_external_msgs(
-                                                        msgs,
-                                                    )?;
+                                                    .handle_batch_external_msgs(msgs)?;
                                             }
                                             Ok(None) => {}
                                             Err(err) => {
-                                                app = app.log_error(
-                                                    err.to_string(),
-                                                )?;
+                                                app = app.log_error(err.to_string())?;
                                             }
                                         }
                                     }
                                     Ok(v) => {
-                                        let res: Result<
-                                            Option<Vec<ExternalMsg>>,
-                                        > = lua
-                                            .from_value(v)
-                                            .map_err(Error::from);
+                                        let res: Result<Option<Vec<ExternalMsg>>> =
+                                            lua.from_value(v).map_err(Error::from);
                                         match res {
                                             Ok(Some(msgs)) => {
                                                 app = app
-                                                    .handle_batch_external_msgs(
-                                                        msgs,
-                                                    )?;
+                                                    .handle_batch_external_msgs(msgs)?;
                                             }
                                             Ok(None) => {}
                                             Err(err) => {
-                                                app = app.log_error(
-                                                    err.to_string(),
-                                                )?;
+                                                app = app.log_error(err.to_string())?;
                                             }
                                         }
                                     }
@@ -632,8 +611,7 @@ impl Runner {
                                             mouse_enabled = true;
                                         }
                                         Err(e) => {
-                                            app =
-                                                app.log_error(e.to_string())?;
+                                            app = app.log_error(e.to_string())?;
                                         }
                                     }
                                 }
@@ -646,9 +624,7 @@ impl Runner {
                                 match res {
                                     Ok(Value::Function(f)) => {
                                         let arg = app.to_lua_ctx_heavy();
-                                        let res: Result<
-                                            Option<Vec<ExternalMsg>>,
-                                        > = lua
+                                        let res: Result<Option<Vec<ExternalMsg>>> = lua
                                             .to_value(&arg)
                                             .and_then(|a| f.call(a))
                                             .and_then(|v| lua.from_value(v))
@@ -656,36 +632,25 @@ impl Runner {
                                         match res {
                                             Ok(Some(msgs)) => {
                                                 app = app
-                                                    .handle_batch_external_msgs(
-                                                        msgs,
-                                                    )?;
+                                                    .handle_batch_external_msgs(msgs)?;
                                             }
                                             Ok(None) => {}
                                             Err(err) => {
-                                                app = app.log_error(
-                                                    err.to_string(),
-                                                )?;
+                                                app = app.log_error(err.to_string())?;
                                             }
                                         }
                                     }
                                     Ok(v) => {
-                                        let res: Result<
-                                            Option<Vec<ExternalMsg>>,
-                                        > = lua
-                                            .from_value(v)
-                                            .map_err(Error::from);
+                                        let res: Result<Option<Vec<ExternalMsg>>> =
+                                            lua.from_value(v).map_err(Error::from);
                                         match res {
                                             Ok(Some(msgs)) => {
                                                 app = app
-                                                    .handle_batch_external_msgs(
-                                                        msgs,
-                                                    )?;
+                                                    .handle_batch_external_msgs(msgs)?;
                                             }
                                             Ok(None) => {}
                                             Err(err) => {
-                                                app = app.log_error(
-                                                    err.to_string(),
-                                                )?;
+                                                app = app.log_error(err.to_string())?;
                                             }
                                         }
                                     }
@@ -726,8 +691,7 @@ impl Runner {
                                 // TODO remove duplicate segment
                                 match pipe::read_all(&app.pipe.msg_in) {
                                     Ok(msgs) => {
-                                        app = app
-                                            .handle_batch_external_msgs(msgs)?;
+                                        app = app.handle_batch_external_msgs(msgs)?;
                                     }
                                     Err(err) => {
                                         app = app.log_error(err.to_string())?;
@@ -754,8 +718,7 @@ impl Runner {
                                             mouse_enabled = true;
                                         }
                                         Err(e) => {
-                                            app =
-                                                app.log_error(e.to_string())?;
+                                            app = app.log_error(e.to_string())?;
                                         }
                                     }
                                 }
@@ -774,8 +737,7 @@ impl Runner {
         terminal.clear()?;
         terminal.set_cursor(0, 0)?;
         execute!(terminal.backend_mut(), term::LeaveAlternateScreen)?;
-        execute!(terminal.backend_mut(), event::DisableMouseCapture)
-            .unwrap_or_default();
+        execute!(terminal.backend_mut(), event::DisableMouseCapture).unwrap_or_default();
         term::disable_raw_mode()?;
         terminal.show_cursor()?;
 
