@@ -4,7 +4,7 @@ use crate::app::{Node, ResolvedNode};
 use crate::config::PanelUiConfig;
 use crate::lua;
 use crate::permissions::Permissions;
-use ansi_to_tui_forked::ansi_to_text;
+use ansi_to_tui::IntoText;
 use indexmap::IndexSet;
 use lazy_static::lazy_static;
 use mlua::Lua;
@@ -41,11 +41,14 @@ fn string_to_text<'a>(string: String) -> Text<'a> {
     if *NO_COLOR {
         Text::raw(string)
     } else {
-        ansi_to_text(string.bytes()).unwrap_or_else(|e| Text::raw(format!("{:?}", e)))
+        string
+            .as_bytes()
+            .into_text()
+            .unwrap_or_else(|e| Text::raw(format!("{:?}", e)))
     }
 }
 
-#[derive(Debug, Clone, Default, Serialize, Deserialize, PartialEq)]
+#[derive(Debug, Clone, Default, Serialize, Deserialize, PartialEq, Eq)]
 #[serde(deny_unknown_fields)]
 pub struct LayoutOptions {
     #[serde(default)]
@@ -71,7 +74,7 @@ impl LayoutOptions {
     }
 }
 
-#[derive(Debug, Clone, Serialize, Deserialize, PartialEq)]
+#[derive(Debug, Clone, Serialize, Deserialize, PartialEq, Eq)]
 #[serde(deny_unknown_fields)]
 pub enum ContentBody {
     /// A paragraph to render
@@ -289,7 +292,7 @@ impl Into<TuiStyle> for Style {
     }
 }
 
-#[derive(Debug, Clone, Copy, Serialize, Deserialize, PartialEq)]
+#[derive(Debug, Clone, Copy, Serialize, Deserialize, PartialEq, Eq)]
 #[serde(deny_unknown_fields)]
 pub enum Constraint {
     Percentage(u16),
@@ -410,6 +413,8 @@ pub struct NodeUiMetadata {
     pub symlink: Option<ResolvedNodeUiMetadata>,
     pub created: Option<u128>,
     pub last_modified: Option<u128>,
+    pub uid: u32,
+    pub gid: u32,
 
     // Extra
     pub index: usize,
@@ -458,6 +463,8 @@ impl NodeUiMetadata {
             symlink: node.symlink.to_owned().map(ResolvedNode::into),
             created: node.created,
             last_modified: node.last_modified,
+            uid: node.uid,
+            gid: node.gid,
             index,
             relative_index,
             is_before_focus,
@@ -1162,7 +1169,7 @@ pub fn draw_custom_content<B: Backend>(
     }
 }
 
-#[derive(Debug, Clone, Copy, Default, PartialEq, Serialize, Deserialize)]
+#[derive(Debug, Clone, Copy, Default, PartialEq, Eq, Serialize, Deserialize)]
 pub struct Rect {
     x: u16,
     y: u16,
